<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AnalyzeGame</name>
    <message>
        <source>(No analysis)</source>
        <translation>(Keine Analyse)</translation>
    </message>
</context>
<context>
    <name>AsciiArtSaveDialog</name>
    <message>
        <source>Export ASCII Art</source>
        <translation>ASCII-Art exportieren</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>Textdateien (*.txt)</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
</context>
<context>
    <name>ComputerColorDialog</name>
    <message>
        <source>Computer Colors</source>
        <translation>Computer-Farben</translation>
    </message>
    <message>
        <source>Computer plays:</source>
        <translation>Computer spielt:</translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation>Blau/Rot</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Blau</translation>
    </message>
    <message>
        <source>Yellow/Green</source>
        <translation>Gelb/Grün</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Grün</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>Gelb</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Rot</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation>Lila</translation>
    </message>
    <message>
        <source>Orange</source>
        <translation>Orange</translation>
    </message>
</context>
<context>
    <name>ExportImageDialog</name>
    <message>
        <source>Export Image</source>
        <translation>Grafik exportieren</translation>
    </message>
    <message>
        <source>Image width:</source>
        <translation>Bildbreite:</translation>
    </message>
</context>
<context>
    <name>GameInfoDialog</name>
    <message>
        <source>Game Info</source>
        <translation>Spielinformation</translation>
    </message>
    <message>
        <source>Player Blue/Red:</source>
        <translation>Spieler Blau/Rot:</translation>
    </message>
    <message>
        <source>Player Blue:</source>
        <translation>Spieler Blau:</translation>
    </message>
    <message>
        <source>Player Yellow/Green:</source>
        <translation>Spieler Gelb/Grün:</translation>
    </message>
    <message>
        <source>Player Green:</source>
        <translation>Spieler Grün:</translation>
    </message>
    <message>
        <source>Player Yellow:</source>
        <translation>Spieler Gelb:</translation>
    </message>
    <message>
        <source>Player Red:</source>
        <translation>Spieler Rot:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Bedenkzeit:</translation>
    </message>
    <message>
        <source>Event:</source>
        <translation>Veranstaltung:</translation>
    </message>
    <message>
        <source>Round:</source>
        <translation>Runde:</translation>
    </message>
    <message>
        <source>Player Purple:</source>
        <translation>Spieler Lila:</translation>
    </message>
    <message>
        <source>Player Orange:</source>
        <translation>Spieler Orange:</translation>
    </message>
</context>
<context>
    <name>GameModel</name>
    <message>
        <source>(Setup)</source>
        <translation>(Stellung)</translation>
    </message>
    <message>
        <source>(No moves)</source>
        <translation>(Keine Züge)</translation>
    </message>
    <message>
        <source>Move %1</source>
        <translation>Zug %1</translation>
    </message>
    <message>
        <source>Blue wins with 1 point.</source>
        <translation>Blau gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Blue wins with %L1 points.</source>
        <translation>Blau gewinnt mit %L1 Punkten.</translation>
    </message>
    <message>
        <source>Green wins with 1 point.</source>
        <translation>Grün gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Green wins with %L1 points.</source>
        <translation>Grün gewinnt mit %L1 Punkten.</translation>
    </message>
    <message>
        <source>Green wins (tie resolved).</source>
        <translation>Grün gewinnt (Unentschieden aufgelöst).</translation>
    </message>
    <message>
        <source>Game ends in a tie.</source>
        <translation>Spiel endet unentschieden.</translation>
    </message>
    <message>
        <source>Blue/Red wins with 1 point.</source>
        <translation>Blau/Rot gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Blue/Red wins with %L1 points.</source>
        <translation>Blau/Rot gewinnt mit %L1 Punkten.</translation>
    </message>
    <message>
        <source>Yellow/Green wins with 1 point.</source>
        <translation>Gelb/Grün gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Yellow/Green wins with %L1 points.</source>
        <translation>Gelb/Grün gewinnt mit %L1 Punkten.</translation>
    </message>
    <message>
        <source>Yellow/Green wins (tie resolved).</source>
        <translation>Gelb/Grün gewinnt (Unentschieden aufgelöst).</translation>
    </message>
    <message>
        <source>Blue wins.</source>
        <translation>Blau gewinnt.</translation>
    </message>
    <message>
        <source>Yellow wins.</source>
        <translation>Gelb gewinnt.</translation>
    </message>
    <message>
        <source>Red wins.</source>
        <translation>Rot gewinnt.</translation>
    </message>
    <message>
        <source>Red wins (tie resolved).</source>
        <translation>Rot gewinnt (Unentschieden aufgelöst).</translation>
    </message>
    <message>
        <source>Yellow wins (tie resolved).</source>
        <translation>Gelb gewinnt (Unentschieden aufgelöst).</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Yellow.</source>
        <translation>Spiel endet in einem Unentschieden zwischen Blau und Gelb.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Red.</source>
        <translation>Spiel endet in einem Unentschieden zwischen Blau und Rot.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow and Red.</source>
        <translation>Spiel endet in einem Unentschieden zwischen Gelb und Rot.</translation>
    </message>
    <message>
        <source>Game ends in a tie between all players.</source>
        <translation>Spiel endet in einem Unentschieden zwischen allen Spielern.</translation>
    </message>
    <message>
        <source>Green wins.</source>
        <translation>Grün gewinnt.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Red.</source>
        <translation>Spiel endet in einem Unentschieden zwischen Blau, Gelb und Rot.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Green.</source>
        <translation>Spiel endet in einem Unentschieden zwischen Blau, Gelb und Grün.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Red and Green.</source>
        <translation>Spiel endet in einem Unentschieden zwischen Blau, Rot und Grün.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow, Red and Green.</source>
        <translation>Spiel endet in einem Unentschieden zwischen Gelb, Rot und Grün.</translation>
    </message>
    <message>
        <source>Clipboard is empty.</source>
        <translation>Zwischenablage ist leer.</translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation>Blau/Rot</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Blau</translation>
    </message>
    <message>
        <source>Yellow/Green</source>
        <translation>Gelb/Grün</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Grün</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>Gelb</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Rot</translation>
    </message>
    <message>
        <source>Invalid Blokus SGF file. (%1)</source>
        <translation>Ungültige Blokus-SGF-Datei. (%1)</translation>
    </message>
    <message>
        <source>File has unsupported character set.</source>
        <translation>Datei hat nicht unterstützten Zeichensatz.</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation>Lila</translation>
    </message>
    <message>
        <source>Orange</source>
        <translation>Orange</translation>
    </message>
    <message>
        <source>Purple wins with 1 point.</source>
        <translation>Lila gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Purple wins with %L1 points.</source>
        <translation>Lila gewinnt mit %L1 Punkten.</translation>
    </message>
    <message>
        <source>Orange wins with 1 point.</source>
        <translation>Orange gewinnt mit 1 Punkt.</translation>
    </message>
    <message>
        <source>Orange wins with %L1 points.</source>
        <translation>Orange gewinnt mit %L1 Punkten.</translation>
    </message>
</context>
<context>
    <name>GotoMoveDialog</name>
    <message>
        <source>Go to Move</source>
        <translation>Gehe zu Zug</translation>
    </message>
    <message>
        <source>Move number:</source>
        <translation>Zugnummer:</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>Pentobi Help</source>
        <translation>Pentobi-Hilfe</translation>
    </message>
</context>
<context>
    <name>ImageSaveDialog</name>
    <message>
        <source>Save Image</source>
        <translation>Grafik speichern</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
    <message>
        <source>PNG image files (*.png)</source>
        <translation>PNG-Bilddateien (*.png)</translation>
    </message>
</context>
<context>
    <name>InitialRatingDialog</name>
    <message>
        <source>Initial Rating</source>
        <translation>Anfangswertung</translation>
    </message>
    <message>
        <source>You have not yet played rated games in this game variant. Estimate your playing strength to initialize your rating.</source>
        <translation>Sie haben noch keine gewerteten Spiele in dieser Spielvariante gespielt. Schätzen Sie Ihre Spielstärke, um Ihre Wertung zu initialisieren.</translation>
    </message>
    <message>
        <source>Beginner</source>
        <translation>Anfänger</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Experte</translation>
    </message>
    <message>
        <source>Your initial rating:</source>
        <translation>Ihre Anfangswertung:</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Pentobi</source>
        <translation>Pentobi</translation>
    </message>
    <message>
        <source>Open failed.</source>
        <translation>Öffnen fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Save failed.</source>
        <translation>Speichern fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Truncate this subtree?</source>
        <translation>Diesen Teilbaum abschneiden?</translation>
    </message>
    <message>
        <source>Truncate children?</source>
        <translation>Kindknoten abschneiden?</translation>
    </message>
    <message>
        <source>Delete all variations?</source>
        <translation>Alle Varianten löschen?</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>Computer opponent for the board game Blokus.</source>
        <translation>Computer-Gegner für das Brettspiel Blokus.</translation>
    </message>
    <message>
        <source>Keep only position?</source>
        <translation>Nur Brettstellung behalten?</translation>
    </message>
    <message>
        <source>Keep only subtree?</source>
        <translation>Nur Teilbaum behalten?</translation>
    </message>
    <message>
        <source>Saving image failed.</source>
        <translation>Grafik konnte nicht gespeichert werden.</translation>
    </message>
    <message>
        <source>Creating image failed.</source>
        <translation>Grafik konnte nicht erzeugt werden.</translation>
    </message>
    <message>
        <source>Game analysis is only possible in main variation.</source>
        <translation>Spielanalyse ist nur in Hauptvariante möglich.</translation>
    </message>
    <message>
        <source>File has been modified by another application. Reload?</source>
        <translation>Datei wurde von einer anderen Anwendung bearbeitet. Neu laden?</translation>
    </message>
    <message>
        <source>File has been modified by another application. Save anyway?</source>
        <translation>Datei wurde von einer anderen Anwendung bearbeitet. Trotzdem speichern?</translation>
    </message>
    <message>
        <source>End of tree was reached. Continue search from start of the tree?</source>
        <translation>Ende des Spielbaums erreicht. Suche vom Start des Spielbaums fortsetzen?</translation>
    </message>
    <message>
        <source>No comment found</source>
        <translation>Kein Kommentar gefunden</translation>
    </message>
    <message>
        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Blau/Rot gegen Pentobi Spielstufe %1 beginnen?</translation>
    </message>
    <message>
        <source>Start rated game with Blue against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Blau gegen Pentobi Spielstufe %1 beginnen?</translation>
    </message>
    <message>
        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Gelb/Grün gegen Pentobi Spielstufe %1 beginnen?</translation>
    </message>
    <message>
        <source>Start rated game with Green against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Grün gegen Pentobi Spielstufe %1 beginnen?</translation>
    </message>
    <message>
        <source>Start rated game with Yellow against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Gelb gegen Pentobi Spielstufe %1 beginnen?</translation>
    </message>
    <message>
        <source>Start rated game with Red against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Rot gegen Pentobi Spielstufe %1 beginnen?</translation>
    </message>
    <message>
        <source>Your rating has increased from %1 to %2.</source>
        <translation>Ihre Wertung hat sich von %1 auf %2 erhöht.</translation>
    </message>
    <message>
        <source>Your rating has decreased from %1 to %2.</source>
        <translation>Ihre Wertung hat sich von %1 auf %2 verringert.</translation>
    </message>
    <message>
        <source>Your rating stays at %1.</source>
        <translation>Ihre Wertung bleibt bei %1.</translation>
    </message>
    <message>
        <source>Delete all rating information for the current game variant?</source>
        <translation>Alle Wertungsinformationen für die gegenwärtige Spielvariante löschen?</translation>
    </message>
    <message>
        <source>Rating information deleted.</source>
        <translation>Wertungsinformationen gelöscht.</translation>
    </message>
    <message>
        <source>File saved.</source>
        <translation>Datei gespeichert.</translation>
    </message>
    <message>
        <source>Copyright 2011-%1 Markus&amp;nbsp;Enzenberger</source>
        <translation>Copyright 2011-%1 Markus&amp;nbsp;Enzenberger</translation>
    </message>
    <message>
        <source>Game analysis aborted.</source>
        <translation>Spielanalyse abgebrochen.</translation>
    </message>
    <message>
        <source>Computer move aborted.</source>
        <translation>Computer-Zug abgebrochen.</translation>
    </message>
    <message>
        <source>Variations deleted.</source>
        <translation>Varianten gelöscht.</translation>
    </message>
    <message>
        <source>Image saved.</source>
        <translation>Grafik gespeichert.</translation>
    </message>
    <message>
        <source>Kept only position.</source>
        <translation>Nur Brettstellung behalten.</translation>
    </message>
    <message>
        <source>Kept only subtree.</source>
        <translation>Nur Teilbaum behalten.</translation>
    </message>
    <message>
        <source>Children truncated.</source>
        <translation>Kindknoten abgeschnitten.</translation>
    </message>
    <message>
        <source>Variation is now %1.</source>
        <translation>Variante ist jetzt %1.</translation>
    </message>
    <message>
        <source>Discard game?</source>
        <translation>Spiel verwerfen?</translation>
    </message>
    <message>
        <source>File was deleted by another application.</source>
        <translation>Datei wurde von einer anderen Anwendung gelöscht.</translation>
    </message>
    <message>
        <source>Overwrite existing file?</source>
        <translation>Existierende Datei überschreiben?</translation>
    </message>
    <message>
        <source>Start rated game with Purple against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Lila gegen Pentobi Spielstufe %1 beginnen?</translation>
    </message>
    <message>
        <source>Start rated game with Orange against Pentobi level %1?</source>
        <translation>Gewertetes Spiel mit Orange gegen Pentobi Spielstufe %1 beginnen?</translation>
    </message>
</context>
<context>
    <name>MenuComputer</name>
    <message>
        <source>&amp;Computer</source>
        <translation>&amp;Computer</translation>
    </message>
    <message>
        <source>Computer &amp;Colors</source>
        <translation>Computer-&amp;Farben</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Spielen</translation>
    </message>
    <message>
        <source>&amp;Level (Classic, 4 Players)</source>
        <translation>Spielst&amp;ufe (Klassisch, 4 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Classic, 2 Players)</source>
        <translation>Spielst&amp;ufe (Klassisch, 2 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Classic, 3 Players)</source>
        <translation>Spielst&amp;ufe (Klassisch, 3 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Duo)</source>
        <translation>Spielst&amp;ufe (Duo)</translation>
    </message>
    <message>
        <source>&amp;Level (Junior)</source>
        <translation>Spielst&amp;ufe (Junior)</translation>
    </message>
    <message>
        <source>&amp;Level (Trigon, 4 Players)</source>
        <translation>Spielst&amp;ufe (Trigon, 4 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Trigon, 2 Players)</source>
        <translation>Spielst&amp;ufe (Trigon, 2 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Trigon, 3 Players)</source>
        <translation>Spielst&amp;ufe (Trigon, 3 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Nexos, 4 Players)</source>
        <translation>Spielst&amp;ufe (Nexos, 4 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Nexos, 2 Players)</source>
        <translation>Spielst&amp;ufe (Nexos, 2 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Callisto, 4 Players)</source>
        <translation>Spielst&amp;ufe (Callisto, 4 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (Callisto, 3 Players)</source>
        <translation>Spielst&amp;ufe (Callisto, 3 Spieler)</translation>
    </message>
    <message>
        <source>Play &amp;Single Move</source>
        <translation>&amp;Einzelnen Zug spielen</translation>
    </message>
    <message>
        <source>St&amp;op</source>
        <translation>St&amp;opp</translation>
    </message>
    <message>
        <source>&amp;Level (GembloQ, 4 Players)</source>
        <translation>Spielst&amp;ufe (GembloQ, 2 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (GembloQ, 3 Players)</source>
        <translation>Spielst&amp;ufe (GembloQ, 3 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Level (GembloQ, 2 Players, 2 Colors)</source>
        <translation>Spielst&amp;ufe (GembloQ, 2 Spieler, 2 Farben)</translation>
    </message>
    <message>
        <source>&amp;Level (GembloQ, 2 Players, 4 Colors)</source>
        <translation>Spielst&amp;ufe (GembloQ, 2 Spieler, 4 Farben)</translation>
    </message>
    <message>
        <source>&amp;Level (Callisto, 2 Players, 2 Colors)</source>
        <translation>Spielst&amp;ufe (Callisto, 2 Spieler, 2 Farben)</translation>
    </message>
    <message>
        <source>&amp;Level (Callisto, 2 Players, 4 Colors)</source>
        <translation>Spielst&amp;ufe (Callisto, 2 Spieler, 4 Farben)</translation>
    </message>
</context>
<context>
    <name>MenuEdit</name>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <source>Make &amp;Main Variation</source>
        <translation>Zu &amp;Hauptvariante machen</translation>
    </message>
    <message>
        <source>Move Variation &amp;Up</source>
        <translation>Variante nach &amp;oben schieben</translation>
    </message>
    <message>
        <source>Move Variation &amp;Down</source>
        <translation>Variante nach &amp;unten schieben</translation>
    </message>
    <message>
        <source>&amp;Truncate</source>
        <translation>&amp;Abschneiden</translation>
    </message>
    <message>
        <source>Truncate &amp;Children</source>
        <translation>&amp;Kindknoten abschneiden</translation>
    </message>
    <message>
        <source>&amp;Delete All Variations</source>
        <translation>Alle &amp;Varianten löschen</translation>
    </message>
    <message>
        <source>&amp;Next Color</source>
        <translation>&amp;Nächste Farbe</translation>
    </message>
    <message>
        <source>&amp;Keep Only Position</source>
        <translation>Nur &amp;Brettstellung behalten</translation>
    </message>
    <message>
        <source>Keep Only &amp;Subtree</source>
        <translation>Nur &amp;Teilbaum behalten</translation>
    </message>
    <message>
        <source>Move &amp;Annotation</source>
        <translation>&amp;Zugkommentierung</translation>
    </message>
    <message>
        <source>&amp;None</source>
        <translation>&amp;Keine</translation>
    </message>
    <message>
        <source>&amp;Very good</source>
        <translation>&amp;Sehr gut</translation>
    </message>
    <message>
        <source>&amp;Good</source>
        <translation>&amp;Gut</translation>
    </message>
    <message>
        <source>&amp;Doubtful</source>
        <translation>&amp;Zweifelhaft</translation>
    </message>
    <message>
        <source>&amp;Bad</source>
        <translation>S&amp;chlecht</translation>
    </message>
    <message>
        <source>Very B&amp;ad</source>
        <translation>Se&amp;hr schlecht</translation>
    </message>
    <message>
        <source>Int&amp;eresting</source>
        <translation>Int&amp;eressant</translation>
    </message>
    <message>
        <source>S&amp;etup Mode</source>
        <translation>&amp;Stellungsaufbau</translation>
    </message>
    <message>
        <source>Made main variation.</source>
        <translation>Zu Hauptvariante gemacht.</translation>
    </message>
</context>
<context>
    <name>MenuGame</name>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spiel</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>Game &amp;Variant</source>
        <translation>Spiel&amp;variante</translation>
    </message>
    <message>
        <source>Classic (&amp;3 Players)</source>
        <translation>Klassisch (&amp;3 Spieler)</translation>
    </message>
    <message>
        <source>Classic (&amp;4 Players)</source>
        <translation>Klassisch (&amp;4 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Duo</source>
        <translation>&amp;Duo</translation>
    </message>
    <message>
        <source>&amp;Junior</source>
        <translation>&amp;Junior</translation>
    </message>
    <message>
        <source>&amp;Undo Move</source>
        <translation>Zug &amp;rückgängig</translation>
    </message>
    <message>
        <source>&amp;Find Move</source>
        <translation>Zug &amp;finden</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>Öffn&amp;en ...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>&amp;Classic</source>
        <translation>&amp;Klassisch</translation>
    </message>
    <message>
        <source>Classic (&amp;2 Players)</source>
        <translation>Klassisch (&amp;2 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Trigon</source>
        <translation>&amp;Trigon</translation>
    </message>
    <message>
        <source>Trigon (&amp;2 Players)</source>
        <translation>Trigon (&amp;2 Spieler)</translation>
    </message>
    <message>
        <source>Trigon (&amp;3 Players)</source>
        <translation>Trigon (&amp;3 Spieler)</translation>
    </message>
    <message>
        <source>Trigon (&amp;4 Players)</source>
        <translation>Trigon (&amp;4 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Nexos</source>
        <translation>&amp;Nexos</translation>
    </message>
    <message>
        <source>Nexos (&amp;2 Players)</source>
        <translation>Nexos (&amp;2 Spieler)</translation>
    </message>
    <message>
        <source>Nexos (&amp;4 Players)</source>
        <translation>Nexos (&amp;4 Spieler)</translation>
    </message>
    <message>
        <source>C&amp;allisto</source>
        <translation>&amp;Callisto</translation>
    </message>
    <message>
        <source>Callisto (&amp;3 Players)</source>
        <translation>Callisto (&amp;3 Spieler)</translation>
    </message>
    <message>
        <source>Callisto (&amp;4 Players)</source>
        <translation>Callisto (&amp;4 Spieler)</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exportieren</translation>
    </message>
    <message>
        <source>&amp;Image</source>
        <translation>&amp;Grafik</translation>
    </message>
    <message>
        <source>&amp;ASCII Art</source>
        <translation>&amp;ASCII-Art</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Speichern &amp;unter ...</translation>
    </message>
    <message>
        <source>&amp;Game Info</source>
        <translation>Spielinf&amp;ormation</translation>
    </message>
    <message>
        <source>Open R&amp;ecent</source>
        <translation>&amp;Zuletzt benutzte Dateien</translation>
    </message>
    <message>
        <source>&amp;Rated Game</source>
        <translation>Ge&amp;wertetes Spiel</translation>
    </message>
    <message>
        <source>Open from &amp;Clipboard</source>
        <translation>Aus &amp;Zwischenablage öffnen</translation>
    </message>
    <message>
        <source>&amp;GembloQ</source>
        <translation>&amp;GembloQ</translation>
    </message>
    <message>
        <source>GembloQ (&amp;2 Players, 2 Colors)</source>
        <translation>GembloQ (&amp;2 Spieler, 2 Farben)</translation>
    </message>
    <message>
        <source>GembloQ (2 &amp;Players, 4 Colors)</source>
        <translation>GembloQ (2 &amp;Spieler, 4 Farben)</translation>
    </message>
    <message>
        <source>GembloQ (&amp;3 Players)</source>
        <translation>GembloQ (&amp;3 Spieler)</translation>
    </message>
    <message>
        <source>GembloQ (&amp;4 Players)</source>
        <translation>GembloQ (&amp;4 Spieler)</translation>
    </message>
    <message>
        <source>Callisto (&amp;2 Players, 2 Colors)</source>
        <translation>Callisto (&amp;2 Spieler, 2 Farben)</translation>
    </message>
    <message>
        <source>Callisto (2 &amp;Players, 4 Colors)</source>
        <translation>Callisto (2 &amp;Spieler, 4 Farben)</translation>
    </message>
</context>
<context>
    <name>MenuGo</name>
    <message>
        <source>G&amp;o</source>
        <translation>&amp;Gehe zu</translation>
    </message>
    <message>
        <source>Back to &amp;Main Variation</source>
        <translation>Zurück zu &amp;Hauptvariante</translation>
    </message>
    <message>
        <source>&amp;Go to Move...</source>
        <translation>&amp;Gehe zu Zug ...</translation>
    </message>
    <message>
        <source>Beginning of Bran&amp;ch</source>
        <translation>Anfang der Verz&amp;weigung</translation>
    </message>
    <message>
        <source>Find Next &amp;Comment</source>
        <translation>Nächsten &amp;Kommentar finden</translation>
    </message>
</context>
<context>
    <name>MenuHelp</name>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;About Pentobi</source>
        <translation>Über &amp;Pentobi</translation>
    </message>
    <message>
        <source>Pentobi &amp;Help</source>
        <translation>Pentobi-&amp;Hilfe</translation>
    </message>
</context>
<context>
    <name>MenuItemLevel</name>
    <message>
        <source>Level &amp;%1</source>
        <translation>Stufe &amp;%1</translation>
    </message>
</context>
<context>
    <name>MenuTools</name>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Extras</translation>
    </message>
    <message>
        <source>&amp;Analyze Game</source>
        <translation>Spiel &amp;analysieren</translation>
    </message>
    <message>
        <source>&amp;Rating</source>
        <translation>&amp;Wertung</translation>
    </message>
    <message>
        <source>&amp;Clear Rating</source>
        <translation>Wertung lö&amp;schen</translation>
    </message>
</context>
<context>
    <name>MenuView</name>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ansicht</translation>
    </message>
    <message>
        <source>&amp;Animate Pieces</source>
        <translation>Spielsteine &amp;animieren</translation>
    </message>
    <message>
        <source>&amp;Coordinates</source>
        <translation>&amp;Koordinaten</translation>
    </message>
    <message>
        <source>&amp;Move Marking</source>
        <translation>&amp;Zugmarkierung</translation>
    </message>
    <message>
        <source>Last With &amp;Dot</source>
        <translation>Letzter mit &amp;Punkt</translation>
    </message>
    <message>
        <source>Last With &amp;Number</source>
        <translation>Letzter mit &amp;Nummer</translation>
    </message>
    <message>
        <source>&amp;All With Number</source>
        <translation>&amp;Alle mit Nummer</translation>
    </message>
    <message>
        <source>N&amp;one</source>
        <translation>&amp;Keine</translation>
    </message>
    <message>
        <source>Show &amp;Variations</source>
        <translation>&amp;Varianten zeigen</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Voll&amp;bild</translation>
    </message>
    <message>
        <source>&amp;Theme</source>
        <translation>&amp;Erscheinungsbild</translation>
    </message>
    <message>
        <source>&amp;Light</source>
        <translation>&amp;Hell</translation>
    </message>
    <message>
        <source>&amp;Dark</source>
        <translation>&amp;Dunkel</translation>
    </message>
</context>
<context>
    <name>OpenDialog</name>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>Blokus games (*.blksgf)</source>
        <translation>Blokus-Partien (*.blksgf)</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
</context>
<context>
    <name>RatingDialog</name>
    <message>
        <source>Rating</source>
        <translation>Wertung</translation>
    </message>
    <message>
        <source>Your rating:</source>
        <translation>Ihre Wertung:</translation>
    </message>
    <message>
        <source>Best previous rating:</source>
        <translation>Beste frühere Wertung:</translation>
    </message>
    <message>
        <source>Classic (2 players)</source>
        <translation>Klassisch (2 Spieler)</translation>
    </message>
    <message>
        <source>Classic (3 players)</source>
        <translation>Klassisch (3 Spieler)</translation>
    </message>
    <message>
        <source>Classic (4 players)</source>
        <translation>Klassisch (4 Spieler)</translation>
    </message>
    <message>
        <source>Duo</source>
        <translation>Duo</translation>
    </message>
    <message>
        <source>Junior</source>
        <translation>Junior</translation>
    </message>
    <message>
        <source>Trigon (2 players)</source>
        <translation>Trigon (2 Spieler)</translation>
    </message>
    <message>
        <source>Trigon (3 players)</source>
        <translation>Trigon (3 Spieler)</translation>
    </message>
    <message>
        <source>Trigon (4 players)</source>
        <translation>Trigon (4 Spieler)</translation>
    </message>
    <message>
        <source>Nexos (2 players)</source>
        <translation>Nexos (2 Spieler)</translation>
    </message>
    <message>
        <source>Nexos (4 players)</source>
        <translation>Nexos (4 Spieler)</translation>
    </message>
    <message>
        <source>Callisto (2 players)</source>
        <translation>Callisto (2 Spieler)</translation>
    </message>
    <message>
        <source>Callisto (3 players)</source>
        <translation>Callisto (3 Spieler)</translation>
    </message>
    <message>
        <source>Callisto (4 players)</source>
        <translation>Callisto (4 Spieler)</translation>
    </message>
    <message>
        <source>Game variant:</source>
        <translation>Spielvariante:</translation>
    </message>
    <message>
        <source>Rated games:</source>
        <translation>Gewertete Spiele:</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Spiel</translation>
    </message>
    <message>
        <source>Your Color</source>
        <translation>Ihre Farbe</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Stufe</translation>
    </message>
    <message>
        <source>Result</source>
        <translation>Ergebnis</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Win</source>
        <translation>Gewinn</translation>
    </message>
    <message>
        <source>Loss</source>
        <translation>Verlust</translation>
    </message>
    <message>
        <source>Tie</source>
        <translation>Unentsch.</translation>
    </message>
    <message>
        <source>Recent development:</source>
        <translation>Aktuelle Entwicklung:</translation>
    </message>
    <message>
        <source>Open Game %1</source>
        <translation>Spiel %1 öffnen</translation>
    </message>
    <message>
        <source>GembloQ (4 players)</source>
        <translation>GembloQ (4 Spieler)</translation>
    </message>
    <message>
        <source>GembloQ (2 players, 2 colors)</source>
        <translation>GembloQ (2 Spieler, 2 Farben)</translation>
    </message>
    <message>
        <source>GembloQ (2 players, 4 colors)</source>
        <translation>GembloQ (2 Spieler, 4 Farben)</translation>
    </message>
    <message>
        <source>GembloQ (3 players)</source>
        <translation>GembloQ (3 Spieler)</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Blokus games (*.blksgf)</source>
        <translation>Blokus-Partien (*.blksgf)</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Alle Dateien (*)</translation>
    </message>
</context>
<context>
    <name>ToolBar</name>
    <message>
        <source>File (modified): %1</source>
        <translation>Datei (geändert): %1</translation>
    </message>
    <message>
        <source>File: %1</source>
        <translation>Datei: %1</translation>
    </message>
    <message>
        <source>Rated</source>
        <translation>Gewertet</translation>
    </message>
    <message>
        <source>Leave setup</source>
        <translation>Aufbau beenden</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Not enough memory.</source>
        <translation>Nicht genügend Speicher.</translation>
    </message>
    <message>
        <source>Pentobi</source>
        <translation>Pentobi</translation>
    </message>
</context>
</TS>
